@@ -6,6 +6,7 @@ from flask import abort as original_flask_abort
 from flask.views import MethodView
 from flask.signals import got_request_exception
 from werkzeug.exceptions import HTTPException, MethodNotAllowed, NotFound
+from werkzeug.http import HTTP_STATUS_CODES
 from flask.ext.restful.utils import unauthorized, error_data, unpack
 from flask.ext.restful.representations.json import output_json
 
@@ -158,7 +159,8 @@ class Api(object):
         if code >= 500:
             self.app.logger.exception("Internal Error")
 
-        if code == 404:
+        if code == 404 and ('message' not in data or
+                            data['message'] == HTTP_STATUS_CODES[404]):
             rules = dict([(re.sub('(<.*>)', '', rule.rule), rule.rule)
                           for rule in self.app.url_map.iter_rules()])
             close_matches = difflib.get_close_matches(request.path, rules.keys())
@@ -168,10 +170,11 @@ class Api(object):
                     data["message"] += ". "
                 else:
                     data["message"] = ""
+
                 data['message'] += 'You have requested this URI [' + request.path + \
-                                   '] but did you mean ' + \
-                                   ' or '.join((rules[match]
-                                   for match in close_matches)) + ' ?'
+                        '] but did you mean ' + \
+                        ' or '.join((rules[match]
+                                     for match in close_matches)) + ' ?'
 
         resp = self.make_response(data, code)
 
